Exception: RubyClaude::AuthenticationError

Inherits:
Error
  • Object
show all
Defined in:
lib/ruby_claude/errors.rb

Overview

Raised when the CLI output or exit status indicates the user is not logged in or that authentication otherwise failed.