Exception: RubyClaude::BinaryNotFoundError

Inherits:
Error
  • Object
show all
Defined in:
lib/ruby_claude/errors.rb

Overview

Raised when the claude binary cannot be found on PATH or executed.

The message explains how to install Claude Code and reminds the user that they must run claude and /login at least once.