Class: RubyClaude::RunResult

Inherits:
Data
  • Object
show all
Defined in:
lib/ruby_claude/runner.rb

Overview

The captured result of a completed subprocess run.

Instance Attribute Summary collapse

Instance Attribute Details

#exit_statusInteger? (readonly)

Returns exit code, or nil if the process was signalled.

Returns:

  • (Integer, nil)

    exit code, or nil if the process was signalled



14
# File 'lib/ruby_claude/runner.rb', line 14

RunResult = Data.define(:stdout, :stderr, :exit_status)

#stderrString (readonly)

Returns captured stderr.

Returns:

  • (String)

    captured stderr



14
# File 'lib/ruby_claude/runner.rb', line 14

RunResult = Data.define(:stdout, :stderr, :exit_status)

#stdoutString? (readonly)

Returns captured stdout (nil when streaming).

Returns:

  • (String, nil)

    captured stdout (nil when streaming)



14
# File 'lib/ruby_claude/runner.rb', line 14

RunResult = Data.define(:stdout, :stderr, :exit_status)